# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/localhost/v2/localhost.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ibc/lightclients/localhost/v2/localhost.proto\x12\x1dibc.lightclients.localhost.v2\x1a\x1fibc/core/client/v1/client.proto\x1a\x14gogoproto/gogo.proto\"Z\n\x0b\x43lientState\x12\x45\n\rlatest_height\x18\x01 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0clatestHeight:\x04\x88\xa0\x1f\x00\x42\x94\x02\n!com.ibc.lightclients.localhost.v2B\x0eLocalhostProtoP\x01ZHgithub.com/cosmos/ibc-go/v8/modules/light-clients/09-localhost;localhost\xa2\x02\x03ILL\xaa\x02\x1dIbc.Lightclients.Localhost.V2\xca\x02\x1dIbc\\Lightclients\\Localhost\\V2\xe2\x02)Ibc\\Lightclients\\Localhost\\V2\\GPBMetadata\xea\x02 Ibc::Lightclients::Localhost::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.localhost.v2.localhost_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ibc.lightclients.localhost.v2B\016LocalhostProtoP\001ZHgithub.com/cosmos/ibc-go/v8/modules/light-clients/09-localhost;localhost\242\002\003ILL\252\002\035Ibc.Lightclients.Localhost.V2\312\002\035Ibc\\Lightclients\\Localhost\\V2\342\002)Ibc\\Lightclients\\Localhost\\V2\\GPBMetadata\352\002 Ibc::Lightclients::Localhost::V2'
  _globals['_CLIENTSTATE'].fields_by_name['latest_height']._loaded_options = None
  _globals['_CLIENTSTATE'].fields_by_name['latest_height']._serialized_options = b'\310\336\037\000'
  _globals['_CLIENTSTATE']._loaded_options = None
  _globals['_CLIENTSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_CLIENTSTATE']._serialized_start=135
  _globals['_CLIENTSTATE']._serialized_end=225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.injective.tokenfactory.v1beta1 import params_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_params__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/tokenfactory/v1beta1/tx.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a+injective/tokenfactory/v1beta1/params.proto\x1a\x11\x61mino/amino.proto\"\xe9\x02\n\x0eMsgCreateDenom\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12/\n\x08subdenom\x18\x02 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"subdenom\"R\x08subdenom\x12#\n\x04name\x18\x03 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"name\"R\x04name\x12)\n\x06symbol\x18\x04 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"symbol\"R\x06symbol\x12/\n\x08\x64\x65\x63imals\x18\x05 \x01(\rB\x13\xf2\xde\x1f\x0fyaml:\"decimals\"R\x08\x64\x65\x63imals\x12\x45\n\x10\x61llow_admin_burn\x18\x06 \x01(\x08\x42\x1b\xf2\xde\x1f\x17yaml:\"allow_admin_burn\"R\x0e\x61llowAdminBurn:3\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*#injective/tokenfactory/create-denom\"\\\n\x16MsgCreateDenomResponse\x12\x42\n\x0fnew_token_denom\x18\x01 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_token_denom\"R\rnewTokenDenom\"\xdc\x01\n\x07MsgMint\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12H\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:\"amount\"R\x06\x61mount\x12/\n\x08receiver\x18\x03 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"receiver\"R\x08receiver:+\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1binjective/tokenfactory/mint\"\x11\n\x0fMsgMintResponse\"\xf8\x01\n\x07MsgBurn\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12H\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:\"amount\"R\x06\x61mount\x12K\n\x0f\x62urnFromAddress\x18\x03 \x01(\tB!\xf2\xde\x1f\x18yaml:\"burn_from_address\"\xa8\xe7\xb0*\x01R\x0f\x62urnFromAddress:+\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1binjective/tokenfactory/burn\"\x11\n\x0fMsgBurnResponse\"\xcb\x01\n\x0eMsgChangeAdmin\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12&\n\x05\x64\x65nom\x18\x02 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"R\x05\x64\x65nom\x12\x31\n\tnew_admin\x18\x03 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"new_admin\"R\x08newAdmin:3\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*#injective/tokenfactory/change-admin\"\x18\n\x16MsgChangeAdminResponse\"\xbe\x03\n\x13MsgSetDenomMetadata\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12R\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x17\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"metadata\"R\x08metadata\x12\x95\x01\n\x13\x61\x64min_burn_disabled\x18\x03 \x01(\x0b\x32\x45.injective.tokenfactory.v1beta1.MsgSetDenomMetadata.AdminBurnDisabledB\x1e\xf2\xde\x1f\x1ayaml:\"admin_burn_disabled\"R\x11\x61\x64minBurnDisabled\x1aU\n\x11\x41\x64minBurnDisabled\x12@\n\x0eshould_disable\x18\x01 \x01(\x08\x42\x19\xf2\xde\x1f\x15yaml:\"should_disable\"R\rshouldDisable:9\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*)injective/tokenfactory/set-denom-metadata\"\x1d\n\x1bMsgSetDenomMetadataResponse\"\xc8\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x44\n\x06params\x18\x02 \x01(\x0b\x32&.injective.tokenfactory.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:7\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*$injective/tokenfactory/update-params\"\x19\n\x17MsgUpdateParamsResponse2\xbf\x05\n\x03Msg\x12u\n\x0b\x43reateDenom\x12..injective.tokenfactory.v1beta1.MsgCreateDenom\x1a\x36.injective.tokenfactory.v1beta1.MsgCreateDenomResponse\x12`\n\x04Mint\x12\'.injective.tokenfactory.v1beta1.MsgMint\x1a/.injective.tokenfactory.v1beta1.MsgMintResponse\x12`\n\x04\x42urn\x12\'.injective.tokenfactory.v1beta1.MsgBurn\x1a/.injective.tokenfactory.v1beta1.MsgBurnResponse\x12u\n\x0b\x43hangeAdmin\x12..injective.tokenfactory.v1beta1.MsgChangeAdmin\x1a\x36.injective.tokenfactory.v1beta1.MsgChangeAdminResponse\x12\x84\x01\n\x10SetDenomMetadata\x12\x33.injective.tokenfactory.v1beta1.MsgSetDenomMetadata\x1a;.injective.tokenfactory.v1beta1.MsgSetDenomMetadataResponse\x12x\n\x0cUpdateParams\x12/.injective.tokenfactory.v1beta1.MsgUpdateParams\x1a\x37.injective.tokenfactory.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x9b\x02\n\"com.injective.tokenfactory.v1beta1B\x07TxProtoP\x01ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\xa2\x02\x03ITX\xaa\x02\x1eInjective.Tokenfactory.V1beta1\xca\x02\x1eInjective\\Tokenfactory\\V1beta1\xe2\x02*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\xea\x02 Injective::Tokenfactory::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.injective.tokenfactory.v1beta1B\007TxProtoP\001ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\242\002\003ITX\252\002\036Injective.Tokenfactory.V1beta1\312\002\036Injective\\Tokenfactory\\V1beta1\342\002*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\352\002 Injective::Tokenfactory::V1beta1'
  _globals['_MSGCREATEDENOM'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCREATEDENOM'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGCREATEDENOM'].fields_by_name['subdenom']._loaded_options = None
  _globals['_MSGCREATEDENOM'].fields_by_name['subdenom']._serialized_options = b'\362\336\037\017yaml:\"subdenom\"'
  _globals['_MSGCREATEDENOM'].fields_by_name['name']._loaded_options = None
  _globals['_MSGCREATEDENOM'].fields_by_name['name']._serialized_options = b'\362\336\037\013yaml:\"name\"'
  _globals['_MSGCREATEDENOM'].fields_by_name['symbol']._loaded_options = None
  _globals['_MSGCREATEDENOM'].fields_by_name['symbol']._serialized_options = b'\362\336\037\ryaml:\"symbol\"'
  _globals['_MSGCREATEDENOM'].fields_by_name['decimals']._loaded_options = None
  _globals['_MSGCREATEDENOM'].fields_by_name['decimals']._serialized_options = b'\362\336\037\017yaml:\"decimals\"'
  _globals['_MSGCREATEDENOM'].fields_by_name['allow_admin_burn']._loaded_options = None
  _globals['_MSGCREATEDENOM'].fields_by_name['allow_admin_burn']._serialized_options = b'\362\336\037\027yaml:\"allow_admin_burn\"'
  _globals['_MSGCREATEDENOM']._loaded_options = None
  _globals['_MSGCREATEDENOM']._serialized_options = b'\202\347\260*\006sender\212\347\260*#injective/tokenfactory/create-denom'
  _globals['_MSGCREATEDENOMRESPONSE'].fields_by_name['new_token_denom']._loaded_options = None
  _globals['_MSGCREATEDENOMRESPONSE'].fields_by_name['new_token_denom']._serialized_options = b'\362\336\037\026yaml:\"new_token_denom\"'
  _globals['_MSGMINT'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGMINT'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGMINT'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGMINT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\362\336\037\ryaml:\"amount\"'
  _globals['_MSGMINT'].fields_by_name['receiver']._loaded_options = None
  _globals['_MSGMINT'].fields_by_name['receiver']._serialized_options = b'\362\336\037\017yaml:\"receiver\"'
  _globals['_MSGMINT']._loaded_options = None
  _globals['_MSGMINT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\033injective/tokenfactory/mint'
  _globals['_MSGBURN'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGBURN'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGBURN'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGBURN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\362\336\037\ryaml:\"amount\"'
  _globals['_MSGBURN'].fields_by_name['burnFromAddress']._loaded_options = None
  _globals['_MSGBURN'].fields_by_name['burnFromAddress']._serialized_options = b'\362\336\037\030yaml:\"burn_from_address\"\250\347\260*\001'
  _globals['_MSGBURN']._loaded_options = None
  _globals['_MSGBURN']._serialized_options = b'\202\347\260*\006sender\212\347\260*\033injective/tokenfactory/burn'
  _globals['_MSGCHANGEADMIN'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCHANGEADMIN'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGCHANGEADMIN'].fields_by_name['denom']._loaded_options = None
  _globals['_MSGCHANGEADMIN'].fields_by_name['denom']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _globals['_MSGCHANGEADMIN'].fields_by_name['new_admin']._loaded_options = None
  _globals['_MSGCHANGEADMIN'].fields_by_name['new_admin']._serialized_options = b'\362\336\037\020yaml:\"new_admin\"'
  _globals['_MSGCHANGEADMIN']._loaded_options = None
  _globals['_MSGCHANGEADMIN']._serialized_options = b'\202\347\260*\006sender\212\347\260*#injective/tokenfactory/change-admin'
  _globals['_MSGSETDENOMMETADATA_ADMINBURNDISABLED'].fields_by_name['should_disable']._loaded_options = None
  _globals['_MSGSETDENOMMETADATA_ADMINBURNDISABLED'].fields_by_name['should_disable']._serialized_options = b'\362\336\037\025yaml:\"should_disable\"'
  _globals['_MSGSETDENOMMETADATA'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGSETDENOMMETADATA'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGSETDENOMMETADATA'].fields_by_name['metadata']._loaded_options = None
  _globals['_MSGSETDENOMMETADATA'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000\362\336\037\017yaml:\"metadata\"'
  _globals['_MSGSETDENOMMETADATA'].fields_by_name['admin_burn_disabled']._loaded_options = None
  _globals['_MSGSETDENOMMETADATA'].fields_by_name['admin_burn_disabled']._serialized_options = b'\362\336\037\032yaml:\"admin_burn_disabled\"'
  _globals['_MSGSETDENOMMETADATA']._loaded_options = None
  _globals['_MSGSETDENOMMETADATA']._serialized_options = b'\202\347\260*\006sender\212\347\260*)injective/tokenfactory/set-denom-metadata'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*$injective/tokenfactory/update-params'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEDENOM']._serialized_start=278
  _globals['_MSGCREATEDENOM']._serialized_end=639
  _globals['_MSGCREATEDENOMRESPONSE']._serialized_start=641
  _globals['_MSGCREATEDENOMRESPONSE']._serialized_end=733
  _globals['_MSGMINT']._serialized_start=736
  _globals['_MSGMINT']._serialized_end=956
  _globals['_MSGMINTRESPONSE']._serialized_start=958
  _globals['_MSGMINTRESPONSE']._serialized_end=975
  _globals['_MSGBURN']._serialized_start=978
  _globals['_MSGBURN']._serialized_end=1226
  _globals['_MSGBURNRESPONSE']._serialized_start=1228
  _globals['_MSGBURNRESPONSE']._serialized_end=1245
  _globals['_MSGCHANGEADMIN']._serialized_start=1248
  _globals['_MSGCHANGEADMIN']._serialized_end=1451
  _globals['_MSGCHANGEADMINRESPONSE']._serialized_start=1453
  _globals['_MSGCHANGEADMINRESPONSE']._serialized_end=1477
  _globals['_MSGSETDENOMMETADATA']._serialized_start=1480
  _globals['_MSGSETDENOMMETADATA']._serialized_end=1926
  _globals['_MSGSETDENOMMETADATA_ADMINBURNDISABLED']._serialized_start=1782
  _globals['_MSGSETDENOMMETADATA_ADMINBURNDISABLED']._serialized_end=1867
  _globals['_MSGSETDENOMMETADATARESPONSE']._serialized_start=1928
  _globals['_MSGSETDENOMMETADATARESPONSE']._serialized_end=1957
  _globals['_MSGUPDATEPARAMS']._serialized_start=1960
  _globals['_MSGUPDATEPARAMS']._serialized_end=2160
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=2162
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=2187
  _globals['_MSG']._serialized_start=2190
  _globals['_MSG']._serialized_end=2893
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63osmwasm/wasm/v1/tx.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xfe\x01\n\x0cMsgStoreCode\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x36\n\x0ewasm_byte_code\x18\x02 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCodeR\x0cwasmByteCode\x12U\n\x16instantiate_permission\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigR\x15instantiatePermission:!\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x11wasm/MsgStoreCodeJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"W\n\x14MsgStoreCodeResponse\x12#\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x1a\n\x08\x63hecksum\x18\x02 \x01(\x0cR\x08\x63hecksum\"\x95\x03\n\x16MsgInstantiateContract\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12.\n\x05\x61\x64min\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05\x61\x64min\x12#\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x14\n\x05label\x18\x04 \x01(\tR\x05label\x12\x38\n\x03msg\x18\x05 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x03msg\x12w\n\x05\x66unds\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x05\x66unds:+\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1bwasm/MsgInstantiateContract\"h\n\x1eMsgInstantiateContractResponse\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\"\xc4\x03\n\x17MsgInstantiateContract2\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12.\n\x05\x61\x64min\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05\x61\x64min\x12#\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x14\n\x05label\x18\x04 \x01(\tR\x05label\x12\x38\n\x03msg\x18\x05 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x03msg\x12w\n\x05\x66unds\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x05\x66unds\x12\x12\n\x04salt\x18\x07 \x01(\x0cR\x04salt\x12\x17\n\x07\x66ix_msg\x18\x08 \x01(\x08R\x06\x66ixMsg:,\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1cwasm/MsgInstantiateContract2\"i\n\x1fMsgInstantiateContract2Response\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\"\xd8\x02\n\x12MsgExecuteContract\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x34\n\x08\x63ontract\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08\x63ontract\x12\x38\n\x03msg\x18\x03 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x03msg\x12w\n\x05\x66unds\x18\x05 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x05\x66unds:\'\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x17wasm/MsgExecuteContract\"0\n\x1aMsgExecuteContractResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\x84\x02\n\x12MsgMigrateContract\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x34\n\x08\x63ontract\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08\x63ontract\x12#\n\x07\x63ode_id\x18\x03 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x38\n\x03msg\x18\x04 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x03msg:\'\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x17wasm/MsgMigrateContract\"0\n\x1aMsgMigrateContractResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\xd4\x01\n\x0eMsgUpdateAdmin\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x35\n\tnew_admin\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08newAdmin\x12\x34\n\x08\x63ontract\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08\x63ontract:#\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x13wasm/MsgUpdateAdmin\"\x18\n\x16MsgUpdateAdminResponse\"\x9b\x01\n\rMsgClearAdmin\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x34\n\x08\x63ontract\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08\x63ontract:\"\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x12wasm/MsgClearAdmin\"\x17\n\x15MsgClearAdminResponse\"\x82\x02\n\x1aMsgUpdateInstantiateConfig\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12#\n\x07\x63ode_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\\\n\x1anew_instantiate_permission\x18\x03 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigR\x18newInstantiatePermission:/\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1fwasm/MsgUpdateInstantiateConfig\"$\n\"MsgUpdateInstantiateConfigResponse\"\xaf\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12;\n\x06params\x18\x02 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params:\'\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x14wasm/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xe2\x01\n\x0fMsgSudoContract\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x34\n\x08\x63ontract\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08\x63ontract\x12\x38\n\x03msg\x18\x03 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x03msg:\'\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x14wasm/MsgSudoContract\"-\n\x17MsgSudoContractResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\xa5\x01\n\x0bMsgPinCodes\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x39\n\x08\x63ode_ids\x18\x02 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\"R\x07\x63odeIds:#\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x10wasm/MsgPinCodes\"\x15\n\x13MsgPinCodesResponse\"\xa9\x01\n\rMsgUnpinCodes\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x39\n\x08\x63ode_ids\x18\x02 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\"R\x07\x63odeIds:%\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x12wasm/MsgUnpinCodes\"\x17\n\x15MsgUnpinCodesResponse\"\x86\x05\n\x1eMsgStoreAndInstantiateContract\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x36\n\x0ewasm_byte_code\x18\x03 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCodeR\x0cwasmByteCode\x12U\n\x16instantiate_permission\x18\x04 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigR\x15instantiatePermission\x12\x1d\n\nunpin_code\x18\x05 \x01(\x08R\tunpinCode\x12.\n\x05\x61\x64min\x18\x06 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05\x61\x64min\x12\x14\n\x05label\x18\x07 \x01(\tR\x05label\x12\x38\n\x03msg\x18\x08 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x03msg\x12w\n\x05\x66unds\x18\t \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x05\x66unds\x12\x16\n\x06source\x18\n \x01(\tR\x06source\x12\x18\n\x07\x62uilder\x18\x0b \x01(\tR\x07\x62uilder\x12\x1b\n\tcode_hash\x18\x0c \x01(\x0cR\x08\x63odeHash:6\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*#wasm/MsgStoreAndInstantiateContract\"p\n&MsgStoreAndInstantiateContractResponse\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\"\xc6\x01\n\x1fMsgAddCodeUploadParamsAddresses\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x32\n\taddresses\x18\x02 \x03(\tB\x14\xf2\xde\x1f\x10yaml:\"addresses\"R\taddresses:7\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*$wasm/MsgAddCodeUploadParamsAddresses\")\n\'MsgAddCodeUploadParamsAddressesResponse\"\xcc\x01\n\"MsgRemoveCodeUploadParamsAddresses\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x32\n\taddresses\x18\x02 \x03(\tB\x14\xf2\xde\x1f\x10yaml:\"addresses\"R\taddresses::\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\'wasm/MsgRemoveCodeUploadParamsAddresses\",\n*MsgRemoveCodeUploadParamsAddressesResponse\"\xed\x02\n\x1aMsgStoreAndMigrateContract\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x36\n\x0ewasm_byte_code\x18\x02 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCodeR\x0cwasmByteCode\x12U\n\x16instantiate_permission\x18\x03 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigR\x15instantiatePermission\x12\x1a\n\x08\x63ontract\x18\x04 \x01(\tR\x08\x63ontract\x12\x38\n\x03msg\x18\x05 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x03msg:2\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x1fwasm/MsgStoreAndMigrateContract\"y\n\"MsgStoreAndMigrateContractResponse\x12#\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x1a\n\x08\x63hecksum\x18\x02 \x01(\x0cR\x08\x63hecksum\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"\xca\x01\n\x16MsgUpdateContractLabel\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x1b\n\tnew_label\x18\x02 \x01(\tR\x08newLabel\x12\x34\n\x08\x63ontract\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08\x63ontract:+\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1bwasm/MsgUpdateContractLabel\" \n\x1eMsgUpdateContractLabelResponse2\xd5\x0e\n\x03Msg\x12S\n\tStoreCode\x12\x1e.cosmwasm.wasm.v1.MsgStoreCode\x1a&.cosmwasm.wasm.v1.MsgStoreCodeResponse\x12q\n\x13InstantiateContract\x12(.cosmwasm.wasm.v1.MsgInstantiateContract\x1a\x30.cosmwasm.wasm.v1.MsgInstantiateContractResponse\x12t\n\x14InstantiateContract2\x12).cosmwasm.wasm.v1.MsgInstantiateContract2\x1a\x31.cosmwasm.wasm.v1.MsgInstantiateContract2Response\x12\x65\n\x0f\x45xecuteContract\x12$.cosmwasm.wasm.v1.MsgExecuteContract\x1a,.cosmwasm.wasm.v1.MsgExecuteContractResponse\x12\x65\n\x0fMigrateContract\x12$.cosmwasm.wasm.v1.MsgMigrateContract\x1a,.cosmwasm.wasm.v1.MsgMigrateContractResponse\x12Y\n\x0bUpdateAdmin\x12 .cosmwasm.wasm.v1.MsgUpdateAdmin\x1a(.cosmwasm.wasm.v1.MsgUpdateAdminResponse\x12V\n\nClearAdmin\x12\x1f.cosmwasm.wasm.v1.MsgClearAdmin\x1a\'.cosmwasm.wasm.v1.MsgClearAdminResponse\x12}\n\x17UpdateInstantiateConfig\x12,.cosmwasm.wasm.v1.MsgUpdateInstantiateConfig\x1a\x34.cosmwasm.wasm.v1.MsgUpdateInstantiateConfigResponse\x12\\\n\x0cUpdateParams\x12!.cosmwasm.wasm.v1.MsgUpdateParams\x1a).cosmwasm.wasm.v1.MsgUpdateParamsResponse\x12\\\n\x0cSudoContract\x12!.cosmwasm.wasm.v1.MsgSudoContract\x1a).cosmwasm.wasm.v1.MsgSudoContractResponse\x12P\n\x08PinCodes\x12\x1d.cosmwasm.wasm.v1.MsgPinCodes\x1a%.cosmwasm.wasm.v1.MsgPinCodesResponse\x12V\n\nUnpinCodes\x12\x1f.cosmwasm.wasm.v1.MsgUnpinCodes\x1a\'.cosmwasm.wasm.v1.MsgUnpinCodesResponse\x12\x89\x01\n\x1bStoreAndInstantiateContract\x12\x30.cosmwasm.wasm.v1.MsgStoreAndInstantiateContract\x1a\x38.cosmwasm.wasm.v1.MsgStoreAndInstantiateContractResponse\x12\x95\x01\n\x1fRemoveCodeUploadParamsAddresses\x12\x34.cosmwasm.wasm.v1.MsgRemoveCodeUploadParamsAddresses\x1a<.cosmwasm.wasm.v1.MsgRemoveCodeUploadParamsAddressesResponse\x12\x8c\x01\n\x1c\x41\x64\x64\x43odeUploadParamsAddresses\x12\x31.cosmwasm.wasm.v1.MsgAddCodeUploadParamsAddresses\x1a\x39.cosmwasm.wasm.v1.MsgAddCodeUploadParamsAddressesResponse\x12}\n\x17StoreAndMigrateContract\x12,.cosmwasm.wasm.v1.MsgStoreAndMigrateContract\x1a\x34.cosmwasm.wasm.v1.MsgStoreAndMigrateContractResponse\x12q\n\x13UpdateContractLabel\x12(.cosmwasm.wasm.v1.MsgUpdateContractLabel\x1a\x30.cosmwasm.wasm.v1.MsgUpdateContractLabelResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xad\x01\n\x14\x63om.cosmwasm.wasm.v1B\x07TxProtoP\x01Z&github.com/CosmWasm/wasmd/x/wasm/types\xa2\x02\x03\x43WX\xaa\x02\x10\x43osmwasm.Wasm.V1\xca\x02\x10\x43osmwasm\\Wasm\\V1\xe2\x02\x1c\x43osmwasm\\Wasm\\V1\\GPBMetadata\xea\x02\x12\x43osmwasm::Wasm::V1\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.cosmwasm.wasm.v1B\007TxProtoP\001Z&github.com/CosmWasm/wasmd/x/wasm/types\242\002\003CWX\252\002\020Cosmwasm.Wasm.V1\312\002\020Cosmwasm\\Wasm\\V1\342\002\034Cosmwasm\\Wasm\\V1\\GPBMetadata\352\002\022Cosmwasm::Wasm::V1\310\341\036\000'
  _globals['_MSGSTORECODE'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGSTORECODE'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSTORECODE'].fields_by_name['wasm_byte_code']._loaded_options = None
  _globals['_MSGSTORECODE'].fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _globals['_MSGSTORECODE']._loaded_options = None
  _globals['_MSGSTORECODE']._serialized_options = b'\202\347\260*\006sender\212\347\260*\021wasm/MsgStoreCode'
  _globals['_MSGSTORECODERESPONSE'].fields_by_name['code_id']._loaded_options = None
  _globals['_MSGSTORECODERESPONSE'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['code_id']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['funds']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT'].fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGINSTANTIATECONTRACT']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\033wasm/MsgInstantiateContract'
  _globals['_MSGINSTANTIATECONTRACTRESPONSE'].fields_by_name['address']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACTRESPONSE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['code_id']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['funds']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT2'].fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGINSTANTIATECONTRACT2']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT2']._serialized_options = b'\202\347\260*\006sender\212\347\260*\034wasm/MsgInstantiateContract2'
  _globals['_MSGINSTANTIATECONTRACT2RESPONSE'].fields_by_name['address']._loaded_options = None
  _globals['_MSGINSTANTIATECONTRACT2RESPONSE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGEXECUTECONTRACT'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGEXECUTECONTRACT'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGEXECUTECONTRACT'].fields_by_name['contract']._loaded_options = None
  _globals['_MSGEXECUTECONTRACT'].fields_by_name['contract']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGEXECUTECONTRACT'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGEXECUTECONTRACT'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_MSGEXECUTECONTRACT'].fields_by_name['funds']._loaded_options = None
  _globals['_MSGEXECUTECONTRACT'].fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGEXECUTECONTRACT']._loaded_options = None
  _globals['_MSGEXECUTECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\027wasm/MsgExecuteContract'
  _globals['_MSGMIGRATECONTRACT'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGMIGRATECONTRACT'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGMIGRATECONTRACT'].fields_by_name['contract']._loaded_options = None
  _globals['_MSGMIGRATECONTRACT'].fields_by_name['contract']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGMIGRATECONTRACT'].fields_by_name['code_id']._loaded_options = None
  _globals['_MSGMIGRATECONTRACT'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_MSGMIGRATECONTRACT'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGMIGRATECONTRACT'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_MSGMIGRATECONTRACT']._loaded_options = None
  _globals['_MSGMIGRATECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\027wasm/MsgMigrateContract'
  _globals['_MSGUPDATEADMIN'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGUPDATEADMIN'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEADMIN'].fields_by_name['new_admin']._loaded_options = None
  _globals['_MSGUPDATEADMIN'].fields_by_name['new_admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEADMIN'].fields_by_name['contract']._loaded_options = None
  _globals['_MSGUPDATEADMIN'].fields_by_name['contract']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEADMIN']._loaded_options = None
  _globals['_MSGUPDATEADMIN']._serialized_options = b'\202\347\260*\006sender\212\347\260*\023wasm/MsgUpdateAdmin'
  _globals['_MSGCLEARADMIN'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCLEARADMIN'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCLEARADMIN'].fields_by_name['contract']._loaded_options = None
  _globals['_MSGCLEARADMIN'].fields_by_name['contract']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCLEARADMIN']._loaded_options = None
  _globals['_MSGCLEARADMIN']._serialized_options = b'\202\347\260*\006sender\212\347\260*\022wasm/MsgClearAdmin'
  _globals['_MSGUPDATEINSTANTIATECONFIG'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGUPDATEINSTANTIATECONFIG'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEINSTANTIATECONFIG'].fields_by_name['code_id']._loaded_options = None
  _globals['_MSGUPDATEINSTANTIATECONFIG'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_MSGUPDATEINSTANTIATECONFIG']._loaded_options = None
  _globals['_MSGUPDATEINSTANTIATECONFIG']._serialized_options = b'\202\347\260*\006sender\212\347\260*\037wasm/MsgUpdateInstantiateConfig'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\024wasm/MsgUpdateParams'
  _globals['_MSGSUDOCONTRACT'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSUDOCONTRACT'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSUDOCONTRACT'].fields_by_name['contract']._loaded_options = None
  _globals['_MSGSUDOCONTRACT'].fields_by_name['contract']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSUDOCONTRACT'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGSUDOCONTRACT'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_MSGSUDOCONTRACT']._loaded_options = None
  _globals['_MSGSUDOCONTRACT']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\024wasm/MsgSudoContract'
  _globals['_MSGPINCODES'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGPINCODES'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGPINCODES'].fields_by_name['code_ids']._loaded_options = None
  _globals['_MSGPINCODES'].fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _globals['_MSGPINCODES']._loaded_options = None
  _globals['_MSGPINCODES']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\020wasm/MsgPinCodes'
  _globals['_MSGUNPINCODES'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUNPINCODES'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUNPINCODES'].fields_by_name['code_ids']._loaded_options = None
  _globals['_MSGUNPINCODES'].fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _globals['_MSGUNPINCODES']._loaded_options = None
  _globals['_MSGUNPINCODES']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\022wasm/MsgUnpinCodes'
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['wasm_byte_code']._loaded_options = None
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['funds']._loaded_options = None
  _globals['_MSGSTOREANDINSTANTIATECONTRACT'].fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGSTOREANDINSTANTIATECONTRACT']._loaded_options = None
  _globals['_MSGSTOREANDINSTANTIATECONTRACT']._serialized_options = b'\202\347\260*\tauthority\212\347\260*#wasm/MsgStoreAndInstantiateContract'
  _globals['_MSGSTOREANDINSTANTIATECONTRACTRESPONSE'].fields_by_name['address']._loaded_options = None
  _globals['_MSGSTOREANDINSTANTIATECONTRACTRESPONSE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSES'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSES'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSES'].fields_by_name['addresses']._loaded_options = None
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSES'].fields_by_name['addresses']._serialized_options = b'\362\336\037\020yaml:\"addresses\"'
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSES']._loaded_options = None
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSES']._serialized_options = b'\202\347\260*\tauthority\212\347\260*$wasm/MsgAddCodeUploadParamsAddresses'
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSES'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSES'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSES'].fields_by_name['addresses']._loaded_options = None
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSES'].fields_by_name['addresses']._serialized_options = b'\362\336\037\020yaml:\"addresses\"'
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSES']._loaded_options = None
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSES']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\'wasm/MsgRemoveCodeUploadParamsAddresses'
  _globals['_MSGSTOREANDMIGRATECONTRACT'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSTOREANDMIGRATECONTRACT'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSTOREANDMIGRATECONTRACT'].fields_by_name['wasm_byte_code']._loaded_options = None
  _globals['_MSGSTOREANDMIGRATECONTRACT'].fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _globals['_MSGSTOREANDMIGRATECONTRACT'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGSTOREANDMIGRATECONTRACT'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_MSGSTOREANDMIGRATECONTRACT']._loaded_options = None
  _globals['_MSGSTOREANDMIGRATECONTRACT']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\037wasm/MsgStoreAndMigrateContract'
  _globals['_MSGSTOREANDMIGRATECONTRACTRESPONSE'].fields_by_name['code_id']._loaded_options = None
  _globals['_MSGSTOREANDMIGRATECONTRACTRESPONSE'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_MSGUPDATECONTRACTLABEL'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGUPDATECONTRACTLABEL'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATECONTRACTLABEL'].fields_by_name['contract']._loaded_options = None
  _globals['_MSGUPDATECONTRACTLABEL'].fields_by_name['contract']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATECONTRACTLABEL']._loaded_options = None
  _globals['_MSGUPDATECONTRACTLABEL']._serialized_options = b'\202\347\260*\006sender\212\347\260*\033wasm/MsgUpdateContractLabel'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSTORECODE']._serialized_start=203
  _globals['_MSGSTORECODE']._serialized_end=457
  _globals['_MSGSTORECODERESPONSE']._serialized_start=459
  _globals['_MSGSTORECODERESPONSE']._serialized_end=546
  _globals['_MSGINSTANTIATECONTRACT']._serialized_start=549
  _globals['_MSGINSTANTIATECONTRACT']._serialized_end=954
  _globals['_MSGINSTANTIATECONTRACTRESPONSE']._serialized_start=956
  _globals['_MSGINSTANTIATECONTRACTRESPONSE']._serialized_end=1060
  _globals['_MSGINSTANTIATECONTRACT2']._serialized_start=1063
  _globals['_MSGINSTANTIATECONTRACT2']._serialized_end=1515
  _globals['_MSGINSTANTIATECONTRACT2RESPONSE']._serialized_start=1517
  _globals['_MSGINSTANTIATECONTRACT2RESPONSE']._serialized_end=1622
  _globals['_MSGEXECUTECONTRACT']._serialized_start=1625
  _globals['_MSGEXECUTECONTRACT']._serialized_end=1969
  _globals['_MSGEXECUTECONTRACTRESPONSE']._serialized_start=1971
  _globals['_MSGEXECUTECONTRACTRESPONSE']._serialized_end=2019
  _globals['_MSGMIGRATECONTRACT']._serialized_start=2022
  _globals['_MSGMIGRATECONTRACT']._serialized_end=2282
  _globals['_MSGMIGRATECONTRACTRESPONSE']._serialized_start=2284
  _globals['_MSGMIGRATECONTRACTRESPONSE']._serialized_end=2332
  _globals['_MSGUPDATEADMIN']._serialized_start=2335
  _globals['_MSGUPDATEADMIN']._serialized_end=2547
  _globals['_MSGUPDATEADMINRESPONSE']._serialized_start=2549
  _globals['_MSGUPDATEADMINRESPONSE']._serialized_end=2573
  _globals['_MSGCLEARADMIN']._serialized_start=2576
  _globals['_MSGCLEARADMIN']._serialized_end=2731
  _globals['_MSGCLEARADMINRESPONSE']._serialized_start=2733
  _globals['_MSGCLEARADMINRESPONSE']._serialized_end=2756
  _globals['_MSGUPDATEINSTANTIATECONFIG']._serialized_start=2759
  _globals['_MSGUPDATEINSTANTIATECONFIG']._serialized_end=3017
  _globals['_MSGUPDATEINSTANTIATECONFIGRESPONSE']._serialized_start=3019
  _globals['_MSGUPDATEINSTANTIATECONFIGRESPONSE']._serialized_end=3055
  _globals['_MSGUPDATEPARAMS']._serialized_start=3058
  _globals['_MSGUPDATEPARAMS']._serialized_end=3233
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=3235
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=3260
  _globals['_MSGSUDOCONTRACT']._serialized_start=3263
  _globals['_MSGSUDOCONTRACT']._serialized_end=3489
  _globals['_MSGSUDOCONTRACTRESPONSE']._serialized_start=3491
  _globals['_MSGSUDOCONTRACTRESPONSE']._serialized_end=3536
  _globals['_MSGPINCODES']._serialized_start=3539
  _globals['_MSGPINCODES']._serialized_end=3704
  _globals['_MSGPINCODESRESPONSE']._serialized_start=3706
  _globals['_MSGPINCODESRESPONSE']._serialized_end=3727
  _globals['_MSGUNPINCODES']._serialized_start=3730
  _globals['_MSGUNPINCODES']._serialized_end=3899
  _globals['_MSGUNPINCODESRESPONSE']._serialized_start=3901
  _globals['_MSGUNPINCODESRESPONSE']._serialized_end=3924
  _globals['_MSGSTOREANDINSTANTIATECONTRACT']._serialized_start=3927
  _globals['_MSGSTOREANDINSTANTIATECONTRACT']._serialized_end=4573
  _globals['_MSGSTOREANDINSTANTIATECONTRACTRESPONSE']._serialized_start=4575
  _globals['_MSGSTOREANDINSTANTIATECONTRACTRESPONSE']._serialized_end=4687
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSES']._serialized_start=4690
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSES']._serialized_end=4888
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSESRESPONSE']._serialized_start=4890
  _globals['_MSGADDCODEUPLOADPARAMSADDRESSESRESPONSE']._serialized_end=4931
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSES']._serialized_start=4934
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSES']._serialized_end=5138
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSESRESPONSE']._serialized_start=5140
  _globals['_MSGREMOVECODEUPLOADPARAMSADDRESSESRESPONSE']._serialized_end=5184
  _globals['_MSGSTOREANDMIGRATECONTRACT']._serialized_start=5187
  _globals['_MSGSTOREANDMIGRATECONTRACT']._serialized_end=5552
  _globals['_MSGSTOREANDMIGRATECONTRACTRESPONSE']._serialized_start=5554
  _globals['_MSGSTOREANDMIGRATECONTRACTRESPONSE']._serialized_end=5675
  _globals['_MSGUPDATECONTRACTLABEL']._serialized_start=5678
  _globals['_MSGUPDATECONTRACTLABEL']._serialized_end=5880
  _globals['_MSGUPDATECONTRACTLABELRESPONSE']._serialized_start=5882
  _globals['_MSGUPDATECONTRACTLABELRESPONSE']._serialized_end=5914
  _globals['_MSG']._serialized_start=5917
  _globals['_MSG']._serialized_end=7794
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/distribution/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cosmos/distribution/v1beta1/genesis.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xad\x01\n\x15\x44\x65legatorWithdrawInfo\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12\x43\n\x10withdraw_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x0fwithdrawAddress:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x87\x02\n!ValidatorOutstandingRewardsRecord\x12N\n\x11validator_address\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12\x87\x01\n\x13outstanding_rewards\x18\x02 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB8\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xa8\xe7\xb0*\x01R\x12outstandingRewards:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xea\x01\n$ValidatorAccumulatedCommissionRecord\x12N\n\x11validator_address\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12h\n\x0b\x61\x63\x63umulated\x18\x02 \x01(\x0b\x32;.cosmos.distribution.v1beta1.ValidatorAccumulatedCommissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0b\x61\x63\x63umulated:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xf2\x01\n ValidatorHistoricalRewardsRecord\x12N\n\x11validator_address\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12\x16\n\x06period\x18\x02 \x01(\x04R\x06period\x12\\\n\x07rewards\x18\x03 \x01(\x0b\x32\x37.cosmos.distribution.v1beta1.ValidatorHistoricalRewardsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07rewards:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xd4\x01\n\x1dValidatorCurrentRewardsRecord\x12N\n\x11validator_address\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12Y\n\x07rewards\x18\x02 \x01(\x0b\x32\x34.cosmos.distribution.v1beta1.ValidatorCurrentRewardsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07rewards:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xa2\x02\n\x1b\x44\x65legatorStartingInfoRecord\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12\x62\n\rstarting_info\x18\x03 \x01(\x0b\x32\x32.cosmos.distribution.v1beta1.DelegatorStartingInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0cstartingInfo:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x96\x02\n\x19ValidatorSlashEventRecord\x12N\n\x11validator_address\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12\x16\n\x06height\x18\x02 \x01(\x04R\x06height\x12\x16\n\x06period\x18\x03 \x01(\x04R\x06period\x12o\n\x15validator_slash_event\x18\x04 \x01(\x0b\x32\x30.cosmos.distribution.v1beta1.ValidatorSlashEventB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x13validatorSlashEvent:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x8c\t\n\x0cGenesisState\x12\x46\n\x06params\x18\x01 \x01(\x0b\x32#.cosmos.distribution.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params\x12J\n\x08\x66\x65\x65_pool\x18\x02 \x01(\x0b\x32$.cosmos.distribution.v1beta1.FeePoolB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07\x66\x65\x65Pool\x12w\n\x18\x64\x65legator_withdraw_infos\x18\x03 \x03(\x0b\x32\x32.cosmos.distribution.v1beta1.DelegatorWithdrawInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x16\x64\x65legatorWithdrawInfos\x12\x45\n\x11previous_proposer\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10previousProposer\x12z\n\x13outstanding_rewards\x18\x05 \x03(\x0b\x32>.cosmos.distribution.v1beta1.ValidatorOutstandingRewardsRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x12outstandingRewards\x12\x98\x01\n!validator_accumulated_commissions\x18\x06 \x03(\x0b\x32\x41.cosmos.distribution.v1beta1.ValidatorAccumulatedCommissionRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x1fvalidatorAccumulatedCommissions\x12\x8a\x01\n\x1cvalidator_historical_rewards\x18\x07 \x03(\x0b\x32=.cosmos.distribution.v1beta1.ValidatorHistoricalRewardsRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x1avalidatorHistoricalRewards\x12\x81\x01\n\x19validator_current_rewards\x18\x08 \x03(\x0b\x32:.cosmos.distribution.v1beta1.ValidatorCurrentRewardsRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x17validatorCurrentRewards\x12}\n\x18\x64\x65legator_starting_infos\x18\t \x03(\x0b\x32\x38.cosmos.distribution.v1beta1.DelegatorStartingInfoRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x16\x64\x65legatorStartingInfos\x12w\n\x16validator_slash_events\x18\n \x03(\x0b\x32\x36.cosmos.distribution.v1beta1.ValidatorSlashEventRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x14validatorSlashEvents:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x42\xf4\x01\n\x1f\x63om.cosmos.distribution.v1beta1B\x0cGenesisProtoP\x01Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa2\x02\x03\x43\x44X\xaa\x02\x1b\x43osmos.Distribution.V1beta1\xca\x02\x1b\x43osmos\\Distribution\\V1beta1\xe2\x02\'Cosmos\\Distribution\\V1beta1\\GPBMetadata\xea\x02\x1d\x43osmos::Distribution::V1beta1\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.cosmos.distribution.v1beta1B\014GenesisProtoP\001Z1github.com/cosmos/cosmos-sdk/x/distribution/types\242\002\003CDX\252\002\033Cosmos.Distribution.V1beta1\312\002\033Cosmos\\Distribution\\V1beta1\342\002\'Cosmos\\Distribution\\V1beta1\\GPBMetadata\352\002\035Cosmos::Distribution::V1beta1\250\342\036\001'
  _globals['_DELEGATORWITHDRAWINFO'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_DELEGATORWITHDRAWINFO'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DELEGATORWITHDRAWINFO'].fields_by_name['withdraw_address']._loaded_options = None
  _globals['_DELEGATORWITHDRAWINFO'].fields_by_name['withdraw_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DELEGATORWITHDRAWINFO']._loaded_options = None
  _globals['_DELEGATORWITHDRAWINFO']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_VALIDATOROUTSTANDINGREWARDSRECORD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_VALIDATOROUTSTANDINGREWARDSRECORD'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_VALIDATOROUTSTANDINGREWARDSRECORD'].fields_by_name['outstanding_rewards']._loaded_options = None
  _globals['_VALIDATOROUTSTANDINGREWARDSRECORD'].fields_by_name['outstanding_rewards']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins\250\347\260*\001'
  _globals['_VALIDATOROUTSTANDINGREWARDSRECORD']._loaded_options = None
  _globals['_VALIDATOROUTSTANDINGREWARDSRECORD']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_VALIDATORACCUMULATEDCOMMISSIONRECORD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_VALIDATORACCUMULATEDCOMMISSIONRECORD'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_VALIDATORACCUMULATEDCOMMISSIONRECORD'].fields_by_name['accumulated']._loaded_options = None
  _globals['_VALIDATORACCUMULATEDCOMMISSIONRECORD'].fields_by_name['accumulated']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATORACCUMULATEDCOMMISSIONRECORD']._loaded_options = None
  _globals['_VALIDATORACCUMULATEDCOMMISSIONRECORD']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_VALIDATORHISTORICALREWARDSRECORD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_VALIDATORHISTORICALREWARDSRECORD'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_VALIDATORHISTORICALREWARDSRECORD'].fields_by_name['rewards']._loaded_options = None
  _globals['_VALIDATORHISTORICALREWARDSRECORD'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATORHISTORICALREWARDSRECORD']._loaded_options = None
  _globals['_VALIDATORHISTORICALREWARDSRECORD']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_VALIDATORCURRENTREWARDSRECORD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_VALIDATORCURRENTREWARDSRECORD'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_VALIDATORCURRENTREWARDSRECORD'].fields_by_name['rewards']._loaded_options = None
  _globals['_VALIDATORCURRENTREWARDSRECORD'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATORCURRENTREWARDSRECORD']._loaded_options = None
  _globals['_VALIDATORCURRENTREWARDSRECORD']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_DELEGATORSTARTINGINFORECORD'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFORECORD'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DELEGATORSTARTINGINFORECORD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFORECORD'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_DELEGATORSTARTINGINFORECORD'].fields_by_name['starting_info']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFORECORD'].fields_by_name['starting_info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DELEGATORSTARTINGINFORECORD']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFORECORD']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_VALIDATORSLASHEVENTRECORD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_VALIDATORSLASHEVENTRECORD'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_VALIDATORSLASHEVENTRECORD'].fields_by_name['validator_slash_event']._loaded_options = None
  _globals['_VALIDATORSLASHEVENTRECORD'].fields_by_name['validator_slash_event']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VALIDATORSLASHEVENTRECORD']._loaded_options = None
  _globals['_VALIDATORSLASHEVENTRECORD']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['fee_pool']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['fee_pool']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['delegator_withdraw_infos']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['delegator_withdraw_infos']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['previous_proposer']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['previous_proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_GENESISSTATE'].fields_by_name['outstanding_rewards']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['outstanding_rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['validator_accumulated_commissions']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['validator_accumulated_commissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['validator_historical_rewards']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['validator_historical_rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['validator_current_rewards']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['validator_current_rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['delegator_starting_infos']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['delegator_starting_infos']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['validator_slash_events']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['validator_slash_events']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._loaded_options = None
  _globals['_GENESISSTATE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_DELEGATORWITHDRAWINFO']._serialized_start=223
  _globals['_DELEGATORWITHDRAWINFO']._serialized_end=396
  _globals['_VALIDATOROUTSTANDINGREWARDSRECORD']._serialized_start=399
  _globals['_VALIDATOROUTSTANDINGREWARDSRECORD']._serialized_end=662
  _globals['_VALIDATORACCUMULATEDCOMMISSIONRECORD']._serialized_start=665
  _globals['_VALIDATORACCUMULATEDCOMMISSIONRECORD']._serialized_end=899
  _globals['_VALIDATORHISTORICALREWARDSRECORD']._serialized_start=902
  _globals['_VALIDATORHISTORICALREWARDSRECORD']._serialized_end=1144
  _globals['_VALIDATORCURRENTREWARDSRECORD']._serialized_start=1147
  _globals['_VALIDATORCURRENTREWARDSRECORD']._serialized_end=1359
  _globals['_DELEGATORSTARTINGINFORECORD']._serialized_start=1362
  _globals['_DELEGATORSTARTINGINFORECORD']._serialized_end=1652
  _globals['_VALIDATORSLASHEVENTRECORD']._serialized_start=1655
  _globals['_VALIDATORSLASHEVENTRECORD']._serialized_end=1933
  _globals['_GENESISSTATE']._serialized_start=1936
  _globals['_GENESISSTATE']._serialized_end=3100
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/slashing.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/slashing/v1beta1/slashing.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xc1\x02\n\x14ValidatorSigningInfo\x12;\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ConsensusAddressStringR\x07\x61\x64\x64ress\x12!\n\x0cstart_height\x18\x02 \x01(\x03R\x0bstartHeight\x12!\n\x0cindex_offset\x18\x03 \x01(\x03R\x0bindexOffset\x12L\n\x0cjailed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x0bjailedUntil\x12\x1e\n\ntombstoned\x18\x05 \x01(\x08R\ntombstoned\x12\x32\n\x15missed_blocks_counter\x18\x06 \x01(\x03R\x13missedBlocksCounter:\x04\xe8\xa0\x1f\x01\"\x8d\x04\n\x06Params\x12\x30\n\x14signed_blocks_window\x18\x01 \x01(\x03R\x12signedBlocksWindow\x12i\n\x15min_signed_per_window\x18\x02 \x01(\x0c\x42\x36\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01R\x12minSignedPerWindow\x12^\n\x16\x64owntime_jail_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x14\x64owntimeJailDuration\x12s\n\x1aslash_fraction_double_sign\x18\x04 \x01(\x0c\x42\x36\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01R\x17slashFractionDoubleSign\x12n\n\x17slash_fraction_downtime\x18\x05 \x01(\x0c\x42\x36\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01R\x15slashFractionDowntime:!\x8a\xe7\xb0*\x1c\x63osmos-sdk/x/slashing/ParamsB\xdd\x01\n\x1b\x63om.cosmos.slashing.v1beta1B\rSlashingProtoP\x01Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa2\x02\x03\x43SX\xaa\x02\x17\x43osmos.Slashing.V1beta1\xca\x02\x17\x43osmos\\Slashing\\V1beta1\xe2\x02#Cosmos\\Slashing\\V1beta1\\GPBMetadata\xea\x02\x19\x43osmos::Slashing::V1beta1\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.slashing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.slashing.v1beta1B\rSlashingProtoP\001Z-github.com/cosmos/cosmos-sdk/x/slashing/types\242\002\003CSX\252\002\027Cosmos.Slashing.V1beta1\312\002\027Cosmos\\Slashing\\V1beta1\342\002#Cosmos\\Slashing\\V1beta1\\GPBMetadata\352\002\031Cosmos::Slashing::V1beta1\250\342\036\001'
  _globals['_VALIDATORSIGNINGINFO'].fields_by_name['address']._loaded_options = None
  _globals['_VALIDATORSIGNINGINFO'].fields_by_name['address']._serialized_options = b'\322\264-\035cosmos.ConsensusAddressString'
  _globals['_VALIDATORSIGNINGINFO'].fields_by_name['jailed_until']._loaded_options = None
  _globals['_VALIDATORSIGNINGINFO'].fields_by_name['jailed_until']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_VALIDATORSIGNINGINFO']._loaded_options = None
  _globals['_VALIDATORSIGNINGINFO']._serialized_options = b'\350\240\037\001'
  _globals['_PARAMS'].fields_by_name['min_signed_per_window']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_signed_per_window']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['downtime_jail_duration']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['downtime_jail_duration']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['slash_fraction_double_sign']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['slash_fraction_double_sign']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['slash_fraction_downtime']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['slash_fraction_downtime']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\212\347\260*\034cosmos-sdk/x/slashing/Params'
  _globals['_VALIDATORSIGNINGINFO']._serialized_start=201
  _globals['_VALIDATORSIGNINGINFO']._serialized_end=522
  _globals['_PARAMS']._serialized_start=525
  _globals['_PARAMS']._serialized_end=1050
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmwasm/wasm/v1/genesis.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xcf\x02\n\x0cGenesisState\x12;\n\x06params\x18\x01 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params\x12J\n\x05\x63odes\x18\x02 \x03(\x0b\x32\x16.cosmwasm.wasm.v1.CodeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x0f\x63odes,omitempty\xa8\xe7\xb0*\x01R\x05\x63odes\x12Z\n\tcontracts\x18\x03 \x03(\x0b\x32\x1a.cosmwasm.wasm.v1.ContractB \xc8\xde\x1f\x00\xea\xde\x1f\x13\x63ontracts,omitempty\xa8\xe7\xb0*\x01R\tcontracts\x12Z\n\tsequences\x18\x04 \x03(\x0b\x32\x1a.cosmwasm.wasm.v1.SequenceB \xc8\xde\x1f\x00\xea\xde\x1f\x13sequences,omitempty\xa8\xe7\xb0*\x01R\tsequences\"\xa6\x01\n\x04\x43ode\x12#\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeIDR\x06\x63odeId\x12\x42\n\tcode_info\x18\x02 \x01(\x0b\x32\x1a.cosmwasm.wasm.v1.CodeInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x08\x63odeInfo\x12\x1d\n\ncode_bytes\x18\x03 \x01(\x0cR\tcodeBytes\x12\x16\n\x06pinned\x18\x04 \x01(\x08R\x06pinned\"\xd5\x02\n\x08\x43ontract\x12\x43\n\x10\x63ontract_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x0f\x63ontractAddress\x12N\n\rcontract_info\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.ContractInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0c\x63ontractInfo\x12I\n\x0e\x63ontract_state\x18\x03 \x03(\x0b\x32\x17.cosmwasm.wasm.v1.ModelB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\rcontractState\x12i\n\x15\x63ontract_code_history\x18\x04 \x03(\x0b\x32*.cosmwasm.wasm.v1.ContractCodeHistoryEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x13\x63ontractCodeHistory\"B\n\x08Sequence\x12 \n\x06id_key\x18\x01 \x01(\x0c\x42\t\xe2\xde\x1f\x05IDKeyR\x05idKey\x12\x14\n\x05value\x18\x02 \x01(\x04R\x05valueB\xae\x01\n\x14\x63om.cosmwasm.wasm.v1B\x0cGenesisProtoP\x01Z&github.com/CosmWasm/wasmd/x/wasm/types\xa2\x02\x03\x43WX\xaa\x02\x10\x43osmwasm.Wasm.V1\xca\x02\x10\x43osmwasm\\Wasm\\V1\xe2\x02\x1c\x43osmwasm\\Wasm\\V1\\GPBMetadata\xea\x02\x12\x43osmwasm::Wasm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.cosmwasm.wasm.v1B\014GenesisProtoP\001Z&github.com/CosmWasm/wasmd/x/wasm/types\242\002\003CWX\252\002\020Cosmwasm.Wasm.V1\312\002\020Cosmwasm\\Wasm\\V1\342\002\034Cosmwasm\\Wasm\\V1\\GPBMetadata\352\002\022Cosmwasm::Wasm::V1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['codes']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['codes']._serialized_options = b'\310\336\037\000\352\336\037\017codes,omitempty\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['contracts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['contracts']._serialized_options = b'\310\336\037\000\352\336\037\023contracts,omitempty\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['sequences']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['sequences']._serialized_options = b'\310\336\037\000\352\336\037\023sequences,omitempty\250\347\260*\001'
  _globals['_CODE'].fields_by_name['code_id']._loaded_options = None
  _globals['_CODE'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CODE'].fields_by_name['code_info']._loaded_options = None
  _globals['_CODE'].fields_by_name['code_info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CONTRACT'].fields_by_name['contract_address']._loaded_options = None
  _globals['_CONTRACT'].fields_by_name['contract_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_CONTRACT'].fields_by_name['contract_info']._loaded_options = None
  _globals['_CONTRACT'].fields_by_name['contract_info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CONTRACT'].fields_by_name['contract_state']._loaded_options = None
  _globals['_CONTRACT'].fields_by_name['contract_state']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CONTRACT'].fields_by_name['contract_code_history']._loaded_options = None
  _globals['_CONTRACT'].fields_by_name['contract_code_history']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_SEQUENCE'].fields_by_name['id_key']._loaded_options = None
  _globals['_SEQUENCE'].fields_by_name['id_key']._serialized_options = b'\342\336\037\005IDKey'
  _globals['_GENESISSTATE']._serialized_start=151
  _globals['_GENESISSTATE']._serialized_end=486
  _globals['_CODE']._serialized_start=489
  _globals['_CODE']._serialized_end=655
  _globals['_CONTRACT']._serialized_start=658
  _globals['_CONTRACT']._serialized_end=999
  _globals['_SEQUENCE']._serialized_start=1001
  _globals['_SEQUENCE']._serialized_end=1067
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/txfees/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.txfees.v1beta1 import txfees_pb2 as injective_dot_txfees_dot_v1beta1_dot_txfees__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/txfees/v1beta1/query.proto\x12\x18injective.txfees.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a%injective/txfees/v1beta1/txfees.proto\"_\n\nEipBaseFee\x12Q\n\x08\x62\x61se_fee\x18\x01 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x0fyaml:\"base_fee\"R\x07\x62\x61seFee\"\x14\n\x12QueryParamsRequest\"U\n\x13QueryParamsResponse\x12>\n\x06params\x18\x01 \x01(\x0b\x32 .injective.txfees.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x18\n\x16QueryEipBaseFeeRequest\"Z\n\x17QueryEipBaseFeeResponse\x12?\n\x08\x62\x61se_fee\x18\x01 \x01(\x0b\x32$.injective.txfees.v1beta1.EipBaseFeeR\x07\x62\x61seFee2\xc4\x02\n\x05Query\x12\x8f\x01\n\x06Params\x12,.injective.txfees.v1beta1.QueryParamsRequest\x1a-.injective.txfees.v1beta1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /injective/txfees/v1beta1/params\x12\xa8\x01\n\rGetEipBaseFee\x12\x30.injective.txfees.v1beta1.QueryEipBaseFeeRequest\x1a\x31.injective.txfees.v1beta1.QueryEipBaseFeeResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/txfees/v1beta1/cur_eip_base_feeB\xfa\x01\n\x1c\x63om.injective.txfees.v1beta1B\nQueryProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/types\xa2\x02\x03ITX\xaa\x02\x18Injective.Txfees.V1beta1\xca\x02\x18Injective\\Txfees\\V1beta1\xe2\x02$Injective\\Txfees\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Txfees::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.txfees.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.txfees.v1beta1B\nQueryProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/types\242\002\003ITX\252\002\030Injective.Txfees.V1beta1\312\002\030Injective\\Txfees\\V1beta1\342\002$Injective\\Txfees\\V1beta1\\GPBMetadata\352\002\032Injective::Txfees::V1beta1'
  _globals['_EIPBASEFEE'].fields_by_name['base_fee']._loaded_options = None
  _globals['_EIPBASEFEE'].fields_by_name['base_fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\017yaml:\"base_fee\"'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\"\022 /injective/txfees/v1beta1/params'
  _globals['_QUERY'].methods_by_name['GetEipBaseFee']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetEipBaseFee']._serialized_options = b'\202\323\344\223\002,\022*/injective/txfees/v1beta1/cur_eip_base_fee'
  _globals['_EIPBASEFEE']._serialized_start=157
  _globals['_EIPBASEFEE']._serialized_end=252
  _globals['_QUERYPARAMSREQUEST']._serialized_start=254
  _globals['_QUERYPARAMSREQUEST']._serialized_end=274
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=276
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=361
  _globals['_QUERYEIPBASEFEEREQUEST']._serialized_start=363
  _globals['_QUERYEIPBASEFEEREQUEST']._serialized_end=387
  _globals['_QUERYEIPBASEFEERESPONSE']._serialized_start=389
  _globals['_QUERYEIPBASEFEERESPONSE']._serialized_end=479
  _globals['_QUERY']._serialized_start=482
  _globals['_QUERY']._serialized_end=806
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.peggy.v1 import msgs_pb2 as injective_dot_peggy_dot_v1_dot_msgs__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ValsetConfirm = channel.unary_unary(
                '/injective.peggy.v1.Msg/ValsetConfirm',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetConfirm.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetConfirmResponse.FromString,
                _registered_method=True)
        self.SendToEth = channel.unary_unary(
                '/injective.peggy.v1.Msg/SendToEth',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSendToEth.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSendToEthResponse.FromString,
                _registered_method=True)
        self.RequestBatch = channel.unary_unary(
                '/injective.peggy.v1.Msg/RequestBatch',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRequestBatch.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRequestBatchResponse.FromString,
                _registered_method=True)
        self.ConfirmBatch = channel.unary_unary(
                '/injective.peggy.v1.Msg/ConfirmBatch',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgConfirmBatch.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgConfirmBatchResponse.FromString,
                _registered_method=True)
        self.DepositClaim = channel.unary_unary(
                '/injective.peggy.v1.Msg/DepositClaim',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgDepositClaim.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgDepositClaimResponse.FromString,
                _registered_method=True)
        self.WithdrawClaim = channel.unary_unary(
                '/injective.peggy.v1.Msg/WithdrawClaim',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgWithdrawClaim.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgWithdrawClaimResponse.FromString,
                _registered_method=True)
        self.ValsetUpdateClaim = channel.unary_unary(
                '/injective.peggy.v1.Msg/ValsetUpdateClaim',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetUpdatedClaim.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetUpdatedClaimResponse.FromString,
                _registered_method=True)
        self.ERC20DeployedClaim = channel.unary_unary(
                '/injective.peggy.v1.Msg/ERC20DeployedClaim',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgERC20DeployedClaim.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgERC20DeployedClaimResponse.FromString,
                _registered_method=True)
        self.SetOrchestratorAddresses = channel.unary_unary(
                '/injective.peggy.v1.Msg/SetOrchestratorAddresses',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSetOrchestratorAddresses.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSetOrchestratorAddressesResponse.FromString,
                _registered_method=True)
        self.CancelSendToEth = channel.unary_unary(
                '/injective.peggy.v1.Msg/CancelSendToEth',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgCancelSendToEth.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgCancelSendToEthResponse.FromString,
                _registered_method=True)
        self.SubmitBadSignatureEvidence = channel.unary_unary(
                '/injective.peggy.v1.Msg/SubmitBadSignatureEvidence',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSubmitBadSignatureEvidence.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSubmitBadSignatureEvidenceResponse.FromString,
                _registered_method=True)
        self.UpdateParams = channel.unary_unary(
                '/injective.peggy.v1.Msg/UpdateParams',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.BlacklistEthereumAddresses = channel.unary_unary(
                '/injective.peggy.v1.Msg/BlacklistEthereumAddresses',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgBlacklistEthereumAddresses.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgBlacklistEthereumAddressesResponse.FromString,
                _registered_method=True)
        self.RevokeEthereumBlacklist = channel.unary_unary(
                '/injective.peggy.v1.Msg/RevokeEthereumBlacklist',
                request_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRevokeEthereumBlacklist.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRevokeEthereumBlacklistResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ValsetConfirm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendToEth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DepositClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValsetUpdateClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ERC20DeployedClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOrchestratorAddresses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelSendToEth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitBadSignatureEvidence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlacklistEthereumAddresses(self, request, context):
        """BlacklistEthereumAddresses adds Ethereum addresses to the peggy blacklist.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeEthereumBlacklist(self, request, context):
        """RevokeEthereumBlacklist removes Ethereum addresses from the peggy
        blacklist.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ValsetConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.ValsetConfirm,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetConfirm.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetConfirmResponse.SerializeToString,
            ),
            'SendToEth': grpc.unary_unary_rpc_method_handler(
                    servicer.SendToEth,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSendToEth.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSendToEthResponse.SerializeToString,
            ),
            'RequestBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestBatch,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRequestBatch.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRequestBatchResponse.SerializeToString,
            ),
            'ConfirmBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmBatch,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgConfirmBatch.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgConfirmBatchResponse.SerializeToString,
            ),
            'DepositClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.DepositClaim,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgDepositClaim.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgDepositClaimResponse.SerializeToString,
            ),
            'WithdrawClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawClaim,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgWithdrawClaim.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgWithdrawClaimResponse.SerializeToString,
            ),
            'ValsetUpdateClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.ValsetUpdateClaim,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetUpdatedClaim.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetUpdatedClaimResponse.SerializeToString,
            ),
            'ERC20DeployedClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.ERC20DeployedClaim,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgERC20DeployedClaim.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgERC20DeployedClaimResponse.SerializeToString,
            ),
            'SetOrchestratorAddresses': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOrchestratorAddresses,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSetOrchestratorAddresses.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSetOrchestratorAddressesResponse.SerializeToString,
            ),
            'CancelSendToEth': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelSendToEth,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgCancelSendToEth.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgCancelSendToEthResponse.SerializeToString,
            ),
            'SubmitBadSignatureEvidence': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitBadSignatureEvidence,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSubmitBadSignatureEvidence.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSubmitBadSignatureEvidenceResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgUpdateParams.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'BlacklistEthereumAddresses': grpc.unary_unary_rpc_method_handler(
                    servicer.BlacklistEthereumAddresses,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgBlacklistEthereumAddresses.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgBlacklistEthereumAddressesResponse.SerializeToString,
            ),
            'RevokeEthereumBlacklist': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeEthereumBlacklist,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRevokeEthereumBlacklist.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRevokeEthereumBlacklistResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.peggy.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.peggy.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ValsetConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/ValsetConfirm',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetConfirm.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetConfirmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendToEth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/SendToEth',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSendToEth.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSendToEthResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RequestBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/RequestBatch',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRequestBatch.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRequestBatchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConfirmBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/ConfirmBatch',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgConfirmBatch.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgConfirmBatchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DepositClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/DepositClaim',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgDepositClaim.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgDepositClaimResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WithdrawClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/WithdrawClaim',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgWithdrawClaim.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgWithdrawClaimResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValsetUpdateClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/ValsetUpdateClaim',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetUpdatedClaim.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgValsetUpdatedClaimResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ERC20DeployedClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/ERC20DeployedClaim',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgERC20DeployedClaim.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgERC20DeployedClaimResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetOrchestratorAddresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/SetOrchestratorAddresses',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSetOrchestratorAddresses.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSetOrchestratorAddressesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelSendToEth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/CancelSendToEth',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgCancelSendToEth.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgCancelSendToEthResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubmitBadSignatureEvidence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/SubmitBadSignatureEvidence',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSubmitBadSignatureEvidence.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgSubmitBadSignatureEvidenceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/UpdateParams',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgUpdateParams.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BlacklistEthereumAddresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/BlacklistEthereumAddresses',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgBlacklistEthereumAddresses.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgBlacklistEthereumAddressesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RevokeEthereumBlacklist(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.peggy.v1.Msg/RevokeEthereumBlacklist',
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRevokeEthereumBlacklist.SerializeToString,
            injective_dot_peggy_dot_v1_dot_msgs__pb2.MsgRevokeEthereumBlacklistResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
